---
jupytext:
  formats: md:myst
  text_representation:
    extension: .md
    format_name: myst
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

(neutralmuts_vignette)=

# Neutral mutations during a simulation

STUB
